@@ -200,7 +200,8 @@ static void read_rc_file_compiled()
         sRFd* pipein = sRFd_new(STDIN_FILENO);
         sWFd* pipeout = sWFd_new(STDOUT_FILENO);
         int rcode = saphire_load_obj(rc_fname
-            , pipeout, pipein, STDERR_FILENO);
+            , pipeout, pipein, STDERR_FILENO, NULL);
+        saphire_sweep();
         sRFd_delete(pipein);
         sWFd_flash(pipeout);
         sWFd_delete(pipeout);
@@ -216,7 +217,8 @@ static void read_rc_file_compiled()
             sRFd* pipein = sRFd_new(STDIN_FILENO);
             sWFd* pipeout = sWFd_new(STDOUT_FILENO);
             int rcode = saphire_load_obj(rc_fname
-                , pipeout, pipein, STDERR_FILENO);
+                , pipeout, pipein, STDERR_FILENO, NULL);
+            saphire_sweep();
             sRFd_delete(pipein);
             sWFd_flash(pipeout);
             sWFd_delete(pipeout);
@@ -244,6 +246,7 @@ static void read_rc_file()
         sWFd* pipeout = sWFd_new(STDOUT_FILENO);
         int rcode = saphire_load(rc_fname
             , pipeout, pipein, STDERR_FILENO);
+        saphire_sweep();
         sRFd_delete(pipein);
         sWFd_flash(pipeout);
         sWFd_delete(pipeout);
@@ -260,6 +263,7 @@ static void read_rc_file()
             sWFd* pipeout = sWFd_new(STDOUT_FILENO);
             int rcode = saphire_load(rc_fname
                 , pipeout, pipein, STDERR_FILENO);
+            saphire_sweep();
             sRFd_delete(pipein);
             sWFd_flash(pipeout);
             sWFd_delete(pipeout);
@@ -516,6 +520,7 @@ static void init_hooks()
     sRFd* pipein = sRFd_new(STDIN_FILENO);
     sWFd* pipeout = sWFd_new(STDOUT_FILENO);
     int rcode = saphire_shell(" def mcd_hook { true }; def atexit_hook { true }; def activate_hook { true }; def cursor_move_hook { true }; def cmdline_hook { true }", NULL, pipeout, pipein, STDERR_FILENO);
+    saphire_sweep();
     sRFd_delete(pipein);
     sWFd_flash(pipeout);
     sWFd_delete(pipeout);
@@ -884,7 +889,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN();
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.0.6", 1);
+    setenv("VERSION", "4.0.7", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -1081,6 +1086,7 @@ int main(int argc, char* argv[])
             string_obj* ret = STRING_NEW("");
             sRFd* rfd = sRFd_new(0);
             saphire_shell3(ret, " pidof mfiler3", "pidof mfiler3", rfd);
+            saphire_sweep();
             sRFd_delete(rfd);
 
             char* p = string_c_str(ret);
@@ -1317,6 +1323,7 @@ int main(int argc, char* argv[])
                 sRFd* pipein = sRFd_new(STDIN_FILENO);
                 sWFd* pipeout = sWFd_new(STDOUT_FILENO);
                 int rcode = saphire_shell(buf + 1, "mfiler3 -e", pipeout, pipein, STDERR_FILENO);
+                saphire_sweep();
                 sRFd_delete(pipein);
                 sWFd_flash(pipeout);
                 sWFd_delete(pipeout);
@@ -1346,6 +1353,8 @@ int main(int argc, char* argv[])
                 string_obj* str = STRING_NEW("");
                 sRFd* rfd = sRFd_new(0);
                 saphire_shell3(str, buf + 1, "mfiler3 -E");
+                saphire_sweep();
+                saphire_sweep();
                 sRFd_delete(rfd);
 
                 int pipe = open(pipe_name, O_WRONLY);
@@ -1365,6 +1374,7 @@ int main(int argc, char* argv[])
     string_obj* ret = STRING_NEW("");
     sRFd* rfd = sRFd_new(0);
     saphire_shell3(ret, " pidof mfiler3", "clean mfiler3 sockets", rfd);
+    saphire_sweep();
     sRFd_delete(rfd);
 
     DIR* dir = opendir(gTempDir);
@@ -1417,6 +1427,7 @@ int main(int argc, char* argv[])
     sRFd* pipein = sRFd_new(STDIN_FILENO);
     sWFd* pipeout = sWFd_new(STDOUT_FILENO);
     int rcode = saphire_shell("atexit_hook", NULL, pipeout, pipein, STDERR_FILENO);
+    saphire_sweep();
     sRFd_delete(pipein);
     sWFd_flash(pipeout);
     sWFd_delete(pipeout);
